"""
MegaHAL - MegaHAL bot for IRC
Copyright (C) 2010  Brian S. Stephan

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from ConfigParser import NoOptionError
import mh_python
import os
import re

from extlib import irclib

from Module import Module

class MegaHAL(Module):

    """Have an annoying, dumb, and hilarious chatterbot on IRC."""

    def priority(self):
        return 95

    def __init__(self, irc, config, server):
        """Upon creation, open the MegaHAL brain and get ready for doing actual stuff."""

        Module.__init__(self, irc, config, server)

        mh_python.initbrain()

    def register_handlers(self):
        """Handle pubmsg/privmsg, so we can learn only from IRC events."""

        self.server.add_global_handler('pubmsg', self.on_pub_or_privmsg, self.priority())
        self.server.add_global_handler('privmsg', self.on_pub_or_privmsg, self.priority())
        self.server.add_global_handler('pubmsg', self.learn_from_irc_event)
        self.server.add_global_handler('privmsg', self.learn_from_irc_event)

    def unregister_handlers(self):
        self.server.remove_global_handler('pubmsg', self.on_pub_or_privmsg)
        self.server.remove_global_handler('privmsg', self.on_pub_or_privmsg)
        self.server.remove_global_handler('pubmsg', self.learn_from_irc_event)
        self.server.remove_global_handler('privmsg', self.learn_from_irc_event)

    def save(self):
        """Sync the megahal brain."""
        mh_python.cleanup()

    def learn_from_irc_event(self, connection, event):
        """Learn text when an irc event happens."""
        what = ''.join(event.arguments()[0])
        mh_python.learn(what)

    def do(self, connection, event, nick, userhost, what, admin_unlocked):
        """Say something on IRC if the bot is being addressed."""

        # i think this megahal module is corrupting the object while walking it,
        # so give it a stupid copy of the string. stupid stupid stupid.
        line = ''.join(what)
        reply = ""
        append_nick = False

        if re.search(connection.get_nickname(), line, re.IGNORECASE) is not None:
            addressed_pattern = '^' + connection.get_nickname() + '[:,]\s+'
            addressed_re = re.compile(addressed_pattern)
            if addressed_re.match(what):
                line = addressed_re.sub('', line)
                append_nick = True

            reply = mh_python.doreply(line)
        elif re.search('^!megahal$', line, re.IGNORECASE) is not None:
            reply = mh_python.doreply('')

        if reply is not "":
            if append_nick:
                reply = nick + ": " + reply
            return self.reply(connection, event, reply)

# vi:tabstop=4:expandtab:autoindent
# kate: indent-mode python;indent-width 4;replace-tabs on;
