"""
Seen - track when a person speaks, and allow data to be queried
Copyright (C) 2010  Brian S. Stephan

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from ConfigParser import NoOptionError
import re

from datetime import datetime
from dateutil.tz import *
from extlib import irclib

from Module import Module

class Seen(Module):

    """Track when people say things in public channels, and report on it."""

    def do(self, connection, event, nick, userhost, what, admin_unlocked):
        # whatever it is, store it
        if not self.config.has_section(self.__class__.__name__):
            self.config.add_section(self.__class__.__name__)

        self.config.set(self.__class__.__name__, nick, userhost + '|:|' + datetime.utcnow().isoformat() + '|:|' + what)

        match = re.search('^!seen\s+(\S+)$', what)
        if match:
            query = match.group(1)
            if query != 'debug':
                try:
                    seendata = self.config.get(self.__class__.__name__, query).split('|:|')
                    converted = datetime.strptime(seendata[1], "%Y-%m-%dT%H:%M:%S.%f").replace(tzinfo=tzutc())
                    replystr = 'last saw ' + query + ' at ' + converted.astimezone(tzlocal()).strftime("%Y/%m/%d %H:%M:%S %Z") + ' saying \'' + seendata[2] + '\''
                    return self.reply(connection, event, replystr)
                except NoOptionError: pass

# vi:tabstop=4:expandtab:autoindent
# kate: indent-mode python;indent-width 4;replace-tabs on;
