"""
TextTransform - assorted text transformations (e.g. rot13)
Copyright (C) 2010  Brian S. Stephan

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import base64
import re

from extlib import irclib

from Module import Module

class TextTransform(Module):
    """
    Do a number of text transformations, like rot13.
    """

    def do(self, connection, event, nick, userhost, what, admin_unlocked):
        """
        Pass the real work on to one of our methods and see if any bite.
        """

        # if the caller replied, this will be the reply and they'll have returned true
        reply = ['']

        if self.rot13(what, reply):
            return self.reply(connection, event, reply[0])
        elif self.base64(what, reply):
            return self.reply(connection, event, reply[0])
        elif self.upper(what, reply):
            return self.reply(connection, event, reply[0])

    def rot13(self, what, reply):
        """
        Apply a rot13 method to the text if first word is 'rot13'.
        """

        match = re.search('^!rot13\s+(.*)$', what)
        if match:
            text = match.group(1)
            reply[0] = text.encode('rot13', 'ignore')
            return True

    def base64(self, what, reply):
        """
        Encode/decode base64 string.
        """

        match = re.search('^!base64\s+encode\s+(.*)$', what)
        if match:
            text = match.group(1)
            reply[0] = base64.encodestring(text).replace('\n','')
            return True

        match = re.search('^!base64\s+decode\s+(.*)$', what)
        if match:
            text = match.group(1)
            reply[0] = base64.decodestring(text).replace('\n','')
            return True

    def upper(self, what, reply):
        """
        Convert a string to uppercase.
        """

        match = re.search('^!upper\s+(.*)$', what)
        if match:
            text = match.group(1)
            reply[0] = text.upper()
            return True

# vi:tabstop=4:expandtab:autoindent
# kate: indent-mode python;indent-width 4;replace-tabs on;
